# WAGTAIL ICONIFY

Library developed for **Wagtail CMS**, its purpose is to provide icon blocks from various libraries

[![Code style: black](https://img.shields.io/badge/code%20style-black-black?style=for-the-badge)](https://github.com/psf/black)
![PyPI - Django Version](https://img.shields.io/pypi/djversions/wagtail?style=for-the-badge) 
![Status](https://img.shields.io/badge/Status-alpha-orange?style=for-the-badge)
---
<br/>

![Wagtail](https://raw.githubusercontent.com/Nefonfo/wagtailiconify/main/wagtail.svg)

#### **Special thanks to [Alex Gleason](https://github.com/alexgleason), as well as for his [wagtail-fontawesome](https://github.com/alexgleason/wagtailfontawesome) library (V4.7), which helped me many times, as well as to support me in part of his code for the configuration of some things**

---

### ACTUAL SUPPORTED ICONS

- FontAwesome V5.15.4

### **INSTALATION**

1. **// TODO: CREATE PIP PACKAGE MODULE**
2. Add to INSTALLED_APPS in settings/base.py
    ```python
    INSTALLED_APPS = [
        ... ,
        'wagtailiconify',
        ...
    ```

### **USE EXAMPLE**

```python
from wagtail.core.models import Page
from wagtail.core.fields import StreamField
from wagtail.admin.edit_handlers import StreamFieldPanel

from wagtailiconify.blocks import FontAwesomeBlock

class HomePage(Page):
    body = StreamField([
        ('icon', FontAwesomeBlock())
    ], null = True, blank = False)

    content_panels = Page.content_panels + [
        StreamFieldPanel('body')
    ]
```

### **CONTRIBUTIONS**

All support for the library is well accepted, in fact I would appreciate it very much since I am the only one who is giving support

Any questions, comments or suggestions can be made known to me with an "Issue" notification or make a contribution with a pull request.

Any closer attention can write to me at: victorarmenta30@gmail.com

### **TODO WORK**
- **Pip package installation (READY)**
- **Remove js empty generated by npm run build**
- Admin icons support (Fontawesome have troubleshoots with Wagtail svg icons )
- Support for FeatherIcons
- More docs for developers
- A niceeeee logo for this little library... **Why not?**